@@ -1,9 +1,11 @@
 const { contextBridge, ipcRenderer } = require("electron");
+import type { Game } from "arrpc";
 import type { Keybind } from "../../@types/keybind.js";
 import type { LegcordWindow } from "../../@types/legcordWindow.d.ts";
 import type { Settings } from "../../@types/settings.js";
 import type { ThemeManifest } from "../../@types/themeManifest.js";
 import type { venmicListObject } from "../venmic.js";
+let windowCallback: (arg0: object) => void;
 
 interface IPCSources {
     id: string;
@@ -77,6 +79,7 @@ contextBridge.exposeInMainWorld("legcord", {
     },
     version: ipcRenderer.sendSync("get-app-version", "app-version") as string,
     platform: ipcRenderer.sendSync("getOS") as string,
+    osRelease: ipcRenderer.sendSync("getOSRelease") as string,
     restart: () => ipcRenderer.send("restart"),
     themes: {
         install: async (url: string) => ipcRenderer.invoke("installBDTheme", url) as Promise<null>,
@@ -88,14 +91,17 @@ contextBridge.exposeInMainWorld("legcord", {
         folder: (id: string) => ipcRenderer.send("openThemeFolder", id),
         openQuickCss: () => ipcRenderer.send("openQuickCss"),
     },
+    rpc: {
+        listen: (callback: () => void) => {
+            windowCallback = callback;
+        },
+        refreshProcessList: () => ipcRenderer.send("refreshProcessList"),
+        getProcessList: () => ipcRenderer.sendSync("getProcessList"),
+        addDetectable: (detectable: Game) => ipcRenderer.send("addDetectable", detectable),
+        getDetectables: () => ipcRenderer.sendSync("getDetectables") as Game[],
+    },
 } as unknown as LegcordWindow);
 
-let windowCallback: (arg0: object) => void;
-contextBridge.exposeInMainWorld("LegcordRPC", {
-    listen: (callback: () => void) => {
-        windowCallback = callback;
-    },
-});
 ipcRenderer.on("rpc", (_event, data: object) => {
     console.log(data);
     windowCallback(data);
