@@ -12,15 +12,18 @@ import {
     getConfig,
     getConfigLocation,
     setConfig,
+    setFirstRun,
+    setup,
 } from "./common/config.js";
 import "./updater.js";
-import { injectElectronFlags } from "./common/flags.js";
+import { getPreset } from "./common/flags.js";
 import { setLang } from "./common/lang.js";
 import { fetchMods } from "./discord/extensions/modloader.js";
 import { createWindow } from "./discord/window.js";
 import { createSetupWindow } from "./setup/main.js";
 import { createSplashWindow } from "./splash/main.js";
 export let settings: Settings;
+export let bypassSetup = false;
 checkForDataFolder();
 checkIfConfigExists();
 
@@ -30,6 +33,16 @@ app.on("render-process-gone", (_event, _webContents, details) => {
     }
 });
 function args(): void {
+    // check for bypass-setup flag
+    if (process.argv.includes("--bypass-setup")) {
+        console.log("Bypassing setup and generating default config...");
+        setup(); // default settings
+        setConfig("doneSetup", true);
+        setFirstRun(false);
+        bypassSetup = true;
+        return;
+    }
+
     let argNum = 2;
     if (process.argv[0] === "electron") argNum++;
     const args = process.argv[argNum];
@@ -44,14 +57,15 @@ function args(): void {
     }
 }
 export async function init(): Promise<void> {
-    if (firstRun === true || undefined) {
-        setLang(new Intl.DateTimeFormat().resolvedOptions().locale);
-        await createSetupWindow();
-    } else {
+    // Skip setup if bypass flag was used
+    if (bypassSetup || !(firstRun === true || undefined)) {
         if (getConfig("skipSplash") === false) {
             void createSplashWindow(); // NOTE - Awaiting will hang at start
         }
         createWindow();
+    } else {
+        setLang(new Intl.DateTimeFormat().resolvedOptions().locale);
+        await createSetupWindow();
     }
 }
 args();
@@ -61,23 +75,37 @@ if (!app.requestSingleInstanceLock() && getConfig("multiInstance") === false) {
     app.quit();
 } else {
     app.setAppUserModelId("app.legcord.Legcord");
+
+    const enableFeatures = new Set(app.commandLine.getSwitchValue("enable-features").split(","));
+    const disableFeatures = new Set(app.commandLine.getSwitchValue("disable-features").split(","));
+    const enableBlinkFeatures = new Set(app.commandLine.getSwitchValue("enable-blink-features").split(","));
+    const disableBlinkFeatures = new Set(app.commandLine.getSwitchValue("disable-blink-features").split(","));
+    // unneeded as the last switch is the applied one, however cleans up the commandline
+    app.commandLine.removeSwitch("enable-features");
+    app.commandLine.removeSwitch("disable-features");
+    app.commandLine.removeSwitch("enable-blink-features");
+    app.commandLine.removeSwitch("disable-blink-features");
+
     // WinRetrieveSuggestionsOnlyOnDemand: Work around electron 13 bug w/ async spellchecking on Windows.
     // HardwareMediaKeyHandling,MediaSessionService: Prevent Discord from registering as a media service.
-    app.commandLine.appendSwitch(
-        "disable-features",
-        "WidgetLayering,WinRetrieveSuggestionsOnlyOnDemand,HardwareMediaKeyHandling,MediaSessionService",
-    ); // fix dev tools layers
+    disableFeatures
+        .add("WidgetLayering")
+        .add("WinRetrieveSuggestionsOnlyOnDemand")
+        .add("HardwareMediaKeyHandling")
+        .add("MediaSessionService");
     // Your data now belongs to CCP
     crashReporter.start({ uploadToServer: false });
     // enable pulseaudio audio sharing on linux
     if (process.platform === "linux") {
-        app.commandLine.appendSwitch("enable-features", "PulseaudioLoopbackForScreenShare");
-        app.commandLine.appendSwitch("disable-features", "WebRtcAllowInputVolumeAdjustment");
+        app.commandLine.appendSwitch("gtk-version", "3");
+        enableFeatures.add("PulseaudioLoopbackForScreenShare");
+        disableFeatures.add("WebRtcAllowInputVolumeAdjustment");
+        app.commandLine.appendSwitch("enable-speech-dispatcher");
     }
     // enable webrtc capturer for wayland
     if (process.platform === "linux" && process.env.XDG_SESSION_TYPE?.toLowerCase() === "wayland") {
-        app.commandLine.appendSwitch("disable-features", "UseMultiPlaneFormatForSoftwareVideo");
-        app.commandLine.appendSwitch("enable-features", "WebRTCPipeWireCapturer");
+        enableFeatures.add("WebRTCPipeWireCapturer");
+        disableFeatures.add("UseMultiPlaneFormatForSoftwareVideo");
         console.log("Wayland detected, using PipeWire for video capture.");
     }
     if (process.platform === "darwin") {
@@ -89,7 +117,12 @@ if (!app.requestSingleInstanceLock() && getConfig("multiInstance") === false) {
 
     app.commandLine.appendSwitch("enable-transparent-visuals");
     checkIfConfigIsBroken();
-    injectElectronFlags();
+    const preset = getPreset();
+    if (preset) {
+        preset.switches.forEach(([key, val]) => app.commandLine.appendSwitch(key, val));
+        preset.enableFeatures.forEach((val) => enableFeatures.add(val));
+        preset.disableFeatures.forEach((val) => disableFeatures.add(val));
+    }
     await fetchMods();
     void import("./discord/extensions/plugin.js"); // load chrome extensions
     console.log(`[Config Manager] Current config: ${readFileSync(getConfigLocation(), "utf-8")}`);
@@ -116,6 +149,7 @@ if (!app.requestSingleInstanceLock() && getConfig("multiInstance") === false) {
     if (getConfig("additionalArguments") === undefined) setConfig("additionalArguments", "");
     if (getConfig("transparency") === undefined) setConfig("transparency", "none");
     if (getConfig("windowStyle") === "transparent") setConfig("windowStyle", "default");
+    if (getConfig("windowStyle") === "rebrand") setConfig("windowStyle", "default");
     if (typeof getConfig("tray") === "boolean") {
         //@ts-expect-error
         if (getConfig("tray") === true) {
@@ -125,13 +159,47 @@ if (!app.requestSingleInstanceLock() && getConfig("multiInstance") === false) {
             setConfig("tray", "disabled");
         }
     }
-    if (getConfig("additionalArguments") !== undefined)
-        app.commandLine.appendArgument(getConfig("additionalArguments"));
+    if (getConfig("additionalArguments") !== undefined) {
+        for (const arg of getConfig("additionalArguments").split(" ")) {
+            if (arg.startsWith("--")) {
+                const [key, val] = arg.substring(2).split("=", 1) as [string, string?];
+                if (val === undefined) {
+                    app.commandLine.appendSwitch(key);
+                } else {
+                    if (key === "enable-features") {
+                        val.split(",").forEach((flag) => enableFeatures.add(flag));
+                    } else if (key === "disable-features") {
+                        val.split(",").forEach((flag) => disableFeatures.add(flag));
+                    } else if (key === "enable-blink-features") {
+                        val.split(",").forEach((flag) => enableBlinkFeatures.add(flag));
+                    } else if (key === "disable-blink-features") {
+                        val.split(",").forEach((flag) => disableBlinkFeatures.add(flag));
+                    } else {
+                        app.commandLine.appendSwitch(key, val);
+                    }
+                }
+            }
+        }
+    }
     if (getConfig("smoothScroll") === false) app.commandLine.appendSwitch("disable-smooth-scrolling");
-    if (getConfig("autoScroll")) app.commandLine.appendSwitch("enable-blink-features", "MiddleClickAutoscroll");
+    if (getConfig("autoScroll")) enableBlinkFeatures.add("MiddleClickAutoscroll");
     if (getConfig("disableHttpCache")) app.commandLine.appendSwitch("disable-http-cache");
 
+    enableFeatures.delete("");
+    disableFeatures.delete("");
+    enableBlinkFeatures.delete("");
+    disableBlinkFeatures.delete("");
+    if (enableFeatures.size > 0) app.commandLine.appendSwitch("enable-features", Array.from(enableFeatures).join(","));
+    if (disableFeatures.size > 0)
+        app.commandLine.appendSwitch("disable-features", Array.from(disableFeatures).join(","));
+    if (enableBlinkFeatures.size > 0)
+        app.commandLine.appendSwitch("enable-blink-features", Array.from(enableBlinkFeatures).join(","));
+    if (disableBlinkFeatures.size > 0)
+        app.commandLine.appendSwitch("disable-blink-features", Array.from(disableBlinkFeatures).join(","));
+
     void app.whenReady().then(async () => {
+        process.on("SIGINT", () => app.quit());
+        process.on("SIGTERM", () => app.quit());
         // Patch for linux bug to ensure things are loaded before window creation (fixes transparency on some linux systems)
         await new Promise<void>((resolve) =>
             setTimeout(() => {
