@@ -1,7 +1,6 @@
 import { Show } from "solid-js";
 import type { Settings } from "../../../@types/settings.js";
 import { DropdownItem } from "../components/DropdownItem.jsx";
-import HeroUpdater from "../components/HeroUpdater.jsx";
 import { TextBoxItem } from "../components/TextBoxItem.jsx";
 import { setConfig, toggleMod } from "../settings.js";
 import classes from "./SettingsPage.module.css";
@@ -16,7 +15,6 @@ const settings = store.settings as Settings;
 export function SettingsPage() {
     return (
         <>
-            <HeroUpdater />
             <Header class={classes.category} tag={HeaderTags.H5}>
                 {store.i18n["settings-category-mods"]}
             </Header>
@@ -73,6 +71,26 @@ export function SettingsPage() {
                 title={store.i18n["settings-transparency"]}
                 note={store.i18n["settings-transparency-desc"]}
                 link="https://github.com/Legcord/Legcord/wiki/Transparency-options"
+                extraItems={
+                    <Show
+                        when={
+                            store.settings.transparency !== "none" &&
+                            window.legcord.platform === "darwin" &&
+                            Number.parseInt(window.legcord.osRelease) >= 25
+                        }
+                    >
+                        <div
+                            style={{
+                                background: "rgba(255, 255, 210, 0.85)",
+                                border: "1px solid #e6c200",
+                                color: "#2d2100",
+                                padding: "12px 16px",
+                            }}
+                        >
+                            {store.i18n["settings-transparency-tahoe-warning"]}
+                        </div>
+                    </Show>
+                }
             >
                 <option value="universal">{store.i18n["settings-transparency-universal"]}</option>
                 <Show when={window.legcord.platform === "win32" || window.legcord.platform === "darwin"}>
